| COSMIC_v3.4 | R Documentation |
Mutational signatures data from COSMIC, Catalogue Of Somatic Mutations In Cancer (v3.4 - October 2023)
COSMIC_v3.4
A list with two elements, signature and etiology.
signature is a list with the same structure as
signature.
etiology is a list with the same structure as
etiology.
The signatures are all genome signatures. See https://cancer.sanger.ac.uk/signatures/.
https://cancer.sanger.ac.uk/signatures/.
sbs96_sig_v3.4 <- COSMIC_v3.4$signature$GRCh37$SBS96
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.