| COSMIC_v3.5 | R Documentation |
Mutational signatures data from COSMIC, Catalogue Of Somatic Mutations In Cancer (v3.5 - November 2025)
COSMIC_v3.5
A list with two elements, signature and etiology.
signature is a list with the same structure as
signature.
etiology is a list with the same structure as
etiology. The etiology information is deprecated
and is no longer being updated. It is not versioned at the COSMIC
website and may not reflect signatures added in recent COSMIC
releases. For authoritative, up-to-date etiologies consult
https://cancer.sanger.ac.uk/signatures/ directly.
The signatures are all genome signatures. See https://cancer.sanger.ac.uk/signatures/.
https://cancer.sanger.ac.uk/signatures/.
sbs96_sig_v3.5 <- COSMIC_v3.5$signature$GRCh37$SBS96
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.