| etiology | R Documentation |
List of mutational signatures' proposed etiology summarized from COSMIC, Catalogue Of Somatic Mutations In Cancer (v3.5 - November 2025)
etiology
A list with the elements:
SBS96
DBS78
ID
Each element is a single-column matrix with rownames being the signature IDs and values being a short string describing the proposed etiology.
In general use get_etiology, which handles new
signatures do not have an element in etiology.
The etiology information is deprecated and is no longer being updated. It is not versioned at the COSMIC website and may not reflect signatures added in recent COSMIC releases. For authoritative, up-to-date etiologies consult https://cancer.sanger.ac.uk/signatures/ directly.
https://cancer.sanger.ac.uk/signatures/.
sbs96_etiology <- etiology$SBS96
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.