get_etiology: Get the proposed etiology of mutational signatures.

View source: R/get_etiology.R

get_etiologyR Documentation

Get the proposed etiology of mutational signatures.

Description

Return the known or hypothesized causes of mutational signatures. The level of evidence supporting the proposed etiologies varies. In addition, some proposed etiologies are more akin to associations than specific, mechanistic causes.

Usage

get_etiology(mutation_type, sig_id)

Arguments

mutation_type

Character string, one of "SBS96", "SBS192", "DBS78", "ID".

sig_id

Character vector with signature ids, e.g. c("SBS3", "SBS5").

Value

A character vector of the same length as sig_id, each element of which is the etiology of the corresponding signature, if available, or else the empty string.

Note

The etiology information is deprecated and is no longer being updated. It is not versioned at the COSMIC website and may not reflect signatures added in recent COSMIC releases. For authoritative, up-to-date etiologies consult https://cancer.sanger.ac.uk/signatures/ directly.

See Also

get_etiology

Examples

get_etiology(mutation_type = "ID", sig_id = c("ID1", "foo", "ID3"))

cosmicsig documentation built on April 21, 2026, 9:06 a.m.