possible_artifacts: Return a character vector of the names of possible signature...

View source: R/possible_artifacts.R

possible_artifactsR Documentation

Return a character vector of the names of possible signature artifacts

Description

Return a character vector of the names of possible signature artifacts

Usage

possible_artifacts()

Value

A character vector of the names of possible signature artifacts.

Examples

artifact_sigs <- possible_artifacts()

cosmicsig documentation built on April 21, 2026, 9:06 a.m.